@@ -524,7 +524,33 @@ def createFlask(name, database, url, name_git, path=os.getcwd()):
         return message, False
 
 
-def createVersion(version):
+def generateBackup(project_name):
+    try:
+        oldPath = os.getcwd()
+        # os.chdir("..")
+        shutil.make_archive(project_name, 'zip', base_dir=project_name)
+        botZip = f'{project_name}.zip'
+        # os.chdir(oldPath)
+        return "OK", True
+    except Exception as e:
+        return str(e), False
+
+
+def reverseChanges(project_name):
+    try:
+        oldPath = os.getcwd()
+        # os.chdir("..")
+        shutil.rmtree(project_name)
+        botZip = f'{project_name}.zip'
+        with ZipFile(botZip, 'r') as zip_ref:
+            zip_ref.extractall(os.getcwd())
+        # os.chdir(oldPath)
+        return "OK", True
+    except Exception as e:
+        return str(e), False
+
+
+def createVersion(version, project_name, old_versions):
     """
         Función encargada de crear nueva version en proyecto django
 
@@ -535,10 +561,43 @@ def createVersion(version):
         Retorno:
             message,result  [Tuple]     Mensaje[String] y result[Boolean]
     """
-    with open('springlabs_pypi/core/baseSerializers.py') as file:
-        mensaje = file.read()
-        print("mensaje")
-        print(mensaje)
+
+    message, result = generateBackup(project_name=project_name)
+    errors = []
+    error_flag = False
+
+    # Crear version en project_name/urls.py
+    # Importar public versions de nueva versión
+    path = f"{project_name}/urls.py"
+    find = "# PUBLIC VERSIONS URLS (Managed by SPRINGLABS_DJANGO)"
+    content = f"from api.v{version}.public_urls import public_urls as public_urls_v{version}"
+    message, result = appendContent(path=path,
+                                    content=content,
+                                    find=find)
+    if result == False:
+        errors.append([message, True])
+
+    # Agregar nueva version a urls_versions
+    find = "urls_versions ="
+    for index, old_version in enumerate(old_versions):
+        if index == 0:
+            public_urls = f" public_urls_v{old_version}"
+        else:
+            public_urls = f" + public_urls_v{old_version}"
+        find = find + public_urls
+    content = find + f" + public_urls_v{version}"
+
+    message, result = findNReplace(path=path,
+                                   content=content,
+                                   find=find)
+    if result == False:
+        errors.append([message, True])
+
+    for error in errors:
+        if error[1] == True:
+            message, result = reverseChanges(project_name=project_name)
+            os.remove(project_name + ".zip")
+            return error[0], False
 
     return "OK", True
 
